#
# spec file for package perl-Set-Object
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Set-Object
Name:           perl-Set-Object
Version:        1.42
Release:        bp156.2.3
Summary:        Set of objects and strings
License:        Artistic-2.0
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RU/RURBAN/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This modules implements a set of objects, that is, an unordered collection
of objects without duplication.

The term _objects_ is applied loosely - for the sake of Set::Object,
anything that is a reference is considered an object.

Set::Object 1.09 and later includes support for inserting scalars
(including the empty string, but excluding 'undef') as well as objects.
This can be thought of as (and is currently implemented as) a degenerate
hash that only has keys and no values. Unlike objects placed into a
Set::Object, scalars that are inserted will be flattened into strings, so
will lose any magic (eg, tie) or other special bits that they went in with;
only strings come out.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc examples README
%license LICENSE

%changelog
* Sat Jan 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.42
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.42, 2022-01-21
  =over
  =item *
  Fix C<%%h={}> warning, by Pauwel Coppieters
  =item *
  add F<examples/slow-sort.pl>. see RT #90070
  =back
* Mon Jan 18 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.41
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.41, 2021-01-17
  =over
  =item *
  Use meta-spec 2, Moose -> dev.requires not runtime.recommends
  (GH #6, RT #134034) by mohawk
  =back
* Mon Jan 20 2020 <timueller+perl@suse.de>
- updated to 1.40
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.40, 2020-01-19
  =over
  =item *
  Fixed perl5.28 regressions (not cperl), for @$set args to other set functions.
  (RT #131345). Fixed by adding missing SvGETMAGIC expansions to all args.
  =item *
  Bumped minimal required perl version to 5.8 for arrayref @$set behavior.
  =item *
  Fixed the smokers and some author tests.
  =back
* Tue Jan  9 2018 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.39, 2018-01-08
  =over
  =item *
  Skip installing Changes.pod (PR #5, kentfredric)
  =back
* Tue Nov 14 2017 coolo@suse.com
- updated to 1.38
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.38, 2017-11-11
  =over
  =item *
  Add test_cover and release targets
  =back
  =head1 1.37, 2017-11-11
  =over
  =item *
  Test fixes for -Ddefault_inc_excludes_dot, RT #120540
  =item *
  Skip failing threads test <= 5.10.0
  =item *
  Add CI hooks
  =back
* Sat Nov 11 2017 coolo@suse.com
- updated to 1.36
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.36, 2017-11-10
  =over
  =item *
  Davem fixed get-magic for the new arguments, fixing
  NetHack-Item L<[perl #132152]|https://rt.perl.org/Public/Bug/Display.html?id=132152>.
  See L<[cpan #123582]|https://rt.cpan.org/Ticket/Display.html?id=123582>
  =item *
  Stabilize F<t/misc/kwalitee.t> test
  =back
* Mon Jun 15 2015 coolo@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-Set-Object/Changes.pod
  =head1 1.35, 2015-06-10
  =over
  =item *
  Change to Artistic License 2.0
  =item *
  Add more misc tests. Add use strict to Set::Object::Weak
  =back
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.34, no changelog
* Tue Jun  4 2013 coolo@suse.com
- updated to 1.31
  Changes.pod patch by Gregor Hermann, debian perl group - RT#85244
  Fixes for 5.16 and newer - RT#83426
  Sort by member names, not the refs.
  Fix wrong weak test with globals. Changed to lexicals and use strict/warnings.
  Fix F<t/misc/segfault.t>, check SvMAGICAL before doing C<mg_find>
  Fixed wrong C format types in warnings and C<SET_OBJECT_MAGIC_backref>.
  Added PREREQ_PMs, make L<Test::LeakTrace> and L<Moose> an optional dependency
  for F<t/misc/more_leaks.t>
- Obsoletes perl-Set-Object-1.28-return_value.diff
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Mon Aug 23 2010 anicka@suse.cz
- update to 1.28
  * Fixed a portability concern for some platforms' C compilers
  (that do not support //-style comments) - RT#52690
  * Valid SIGNATURE file - RT#50492
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Tue Jan 20 2009 anicka@suse.cz
- update to 1.27
  * Fix a typo that affected building against Perls with
  debugging enabled.
  * Methods which destroyed C<$@> due to internal use of
  C<eval> now properly call C<local($@)>
  * Define behaviour when dealing with return values from
  operations on weak sets. No longer hard-coded "Set::Object"
  - may affect Set::Object sub-classes (Sam).
  * more bugfixes
* Fri Jul 25 2008 anicka@suse.cz
- update to 1.25
  * Portability: support Perls before 5.7.3, and make this dependency
  explicit in the F<Makefile.PL>
  * Remove threads test which had inadvertantly slipped into the
  MANIFEST from source control, and add comprehensive documentation
  on the state of thread support in this module.
  * Make behaviour when dealing with items which were C<undef> defined.
* Mon Oct  8 2007 anicka@suse.cz
- update to 1.22
  * Sub-classing interface added; it is now much easier to make
  L<Set::Object> subclasses that return objects other than more
  L<Set::Object>s when subclassing.
* Mon Feb 19 2007 anicka@suse.cz
- update to 1.21
- remove last patch (fixed in upstream, the only change in this
  release)
* Fri Feb 16 2007 anicka@suse.cz
- update to 1.20
  * The C<-E<gt>compare> function was returning "disjoint" for empty
    sets.
  * Document lots of methods that were previously not documented.
  * Fix C<Set::Object::Weak::set()>.  It was not passing its
    arguments to C<Set::Object::Weak-E<gt>new()>, which was very
    broken.
- fix misc/pod_coverage.t
* Thu Jan 25 2007 anicka@suse.cz
- update to 1.19
  * New class C<Set::Object::Weak>, which all weak sets should get
    re-blessed into when you call C<-E<gt>weaken>.  Also added
    alternative methods of constructing weak sets.
  * Fix a memory leak with scalar members (the internal hash used
    to store the items was never being freed).
* Tue Sep 19 2006 anicka@suse.cz
- update to 1.18
  * Add note to man page on compatibility of C<Storable>
    serializations of C<Set::Object>s between revisions.
  * fix build for non-gcc compilers
* Thu Sep 14 2006 anicka@suse.cz
- update to 1.17
  * fix compile problem affecting some platforms
* Tue Jul 18 2006 anicka@suse.cz
- update to 1.16
  * weak reference support
- fix random return value
* Tue Jul 11 2006 anicka@suse.cz
- update to 1.15
- minor release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 anicka@suse.cz
- update to 1.14
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.11
* Thu Aug 19 2004 mjancar@suse.cz
- update to 1.06
* Thu Feb 26 2004 mjancar@suse.cz
- update to 1.05
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Jul 24 2003 mjancar@suse.cz
- update to 1.03a
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Wed Jun 18 2003 coolo@suse.de
- package directories
* Thu May 22 2003 mjancar@suse.cz
- use $RPM_OPT_FLAGS
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Thu Aug  2 2001 rvasice@suse.cz
- initial package release (version 1.02)
